@@ -5,10 +5,12 @@ use warnings;
 use Carp;
 
 require Reddit::Client::VotableThing;
-
+# is_original_content in base class
 use base   qw/Reddit::Client::VotableThing/;
 use fields qw/
+approved_at_utc
 approved_by
+archived
 author
 author_flair_background_color
 author_flair_css_class
@@ -23,6 +25,7 @@ author_premium
 awarders
 banned_at_utc
 banned_by
+brand_safe
 can_gild
 can_mod_post
 category
